@@ -1,4 +1,5 @@
-from enum import Enum, unique
+from mlcf.utils import ListEnum
+from enum import unique
 from typing import Dict, List, Optional, Tuple, Union
 
 import pandas as pd
@@ -10,14 +11,14 @@ from mlcf.envtools.hometools import MlcfHome
 
 
 @unique
-class Partition(Enum):
+class Partition(ListEnum):
     TRAIN: str = "train"
     VALIDATION: str = "validation"
     TEST: str = "test"
 
 
 @unique
-class Field(Enum):
+class Field(ListEnum):
     INPUT: str = "input"
     TARGET: str = "target"
 
@@ -29,8 +30,16 @@ INPUT: str = Field.INPUT.value
 TARGET: str = Field.TARGET.value
 
 
-def get_enum_value(enum, Enum) -> str:
-    return enum.value if isinstance(enum, Enum) else enum
+def get_enum_value(enum, ListEnum) -> str:
+    return enum.value if isinstance(enum, ListEnum) else enum
+
+
+class WTSTColumnIndexException(Exception):
+    pass
+
+
+class WTSTFeaturesException(Exception):
+    pass
 
 
 class WTSTraining(object):
@@ -92,15 +101,15 @@ class WTSTraining(object):
         self.part_str: str
         self.set_partition(partition)
         if len(features) != 0:
-            self._set_features(features)
+            self.set_features(features)
         if index_column is not None:
-            self._set_index_column(index_column)
+            self.set_index_column(index_column)
 
-    def _set_features(self, features: List[str]):
+    def set_features(self, features: List[str]):
         self.features = list(features)
         self.features_has_been_set = True
 
-    def _set_index_column(self, index_column: str):
+    def set_index_column(self, index_column: str):
         self.index_column = index_column
         self.index_column_has_been_set = True
 
@@ -131,7 +140,7 @@ class WTSTraining(object):
             selected_data = data[self.features]
         else:
             selected_data = data
-            self._set_features(data.columns)
+            self.set_features(data.columns)
         if self.project:
             self.project.log.debug(
                 f"[WTST]- Data length {len(selected_data)} will be add to the WTST data."
@@ -143,25 +152,36 @@ class WTSTraining(object):
             *args, **kwargs
         )
 
-        self._add_wts_data(
-            input_ts_data=training_dataset[0],
-            target_ts_data=training_dataset[1],
+        self.add_wtseries(*training_dataset)
+
+    def add_wtseries(
+        self,
+        input_tr_data,
+        target_tr_data,
+        input_val_data,
+        target_val_data,
+        input_te_data,
+        target_te_date
+    ):
+        self.add_one_pair_wtsdata(
+            input_ts_data=input_tr_data,
+            target_ts_data=target_tr_data,
             partition=Partition.TRAIN
         )
 
-        self._add_wts_data(
-            input_ts_data=training_dataset[2],
-            target_ts_data=training_dataset[3],
+        self.add_one_pair_wtsdata(
+            input_ts_data=input_val_data,
+            target_ts_data=target_val_data,
             partition=Partition.VALIDATION
         )
 
-        self._add_wts_data(
-            input_ts_data=training_dataset[4],
-            target_ts_data=training_dataset[5],
+        self.add_one_pair_wtsdata(
+            input_ts_data=input_te_data,
+            target_ts_data=target_te_date,
             partition=Partition.TEST
         )
         if self.project:
-            self.project.log.debug(f"[WTST]- New WTST data: {self}")
+            self.project.log.debug(f"[WTST]- Add WTSeries data: {self}")
 
     def get(
         self,
@@ -284,6 +304,30 @@ class WTSTraining(object):
             + f"Test: {self.len(Partition.TEST)}"
         )
 
+    def check_wtsdata(self, wtsdata: WTSeries):
+        data = wtsdata.copy()
+
+        if self.index_column_has_been_set and data[0].index.name != self.index_column:
+            raise WTSTColumnIndexException(
+                f"The WTSeries index : {data[0].index.name} is not equal " +
+                f"to the WTSTraining index : {self.index_column}")
+
+        if self.features_has_been_set and list(data[0].columns) != self.features:
+            raise WTSTFeaturesException(
+                f"The WTSeries features : {list(data[0].columns)} are " +
+                f"not equals to the WTSTraining features : {self.features}")
+        return True
+
+    def add_one_pair_wtsdata(
+        self,
+        input_ts_data: WTSeries,
+        target_ts_data: WTSeries,
+        partition: Partition,
+    ):
+        assert self.check_wtsdata(input_ts_data)
+        assert self.check_wtsdata(target_ts_data)
+        self._add_wts_data(input_ts_data, target_ts_data, partition)
+
     def _add_wts_data(
         self,
         input_ts_data: WTSeries,
